@@ -48,7 +48,7 @@ def iglob(pathname):
 
 def glob1(dirname, pattern):
     if not dirname:
-        dirname = os.curdir
+        dirname = storage.location
     try:
         directories, files = storage.listdir(dirname)
         names = directories + files
